[![Build Status](https://travis-ci.org/kstaniek/condoor.svg?branch=master)](https://travis-ci.org/kstaniek/condoor)

Condoor
=======

Important Links
---------------

Documentation: [https://kstaniek.github.io/condoor/index.html](https://kstaniek.github.io/condoor/index.html)


License
-------

Apache 2.0